@@ -50,18 +50,24 @@ define("P_TEST_LICENSE", "PhoronixTestSuite/TestProfile/License"); // Test softw
 define("P_TEST_STATUS", "PhoronixTestSuite/TestProfile/Status"); // The status of the test profile
 define("P_TEST_SUPPORTEDARCHS", "PhoronixTestSuite/TestProfile/SupportedArchitectures"); // The system architectures supported by this test
 define("P_TEST_SUPPORTEDPLATFORMS", "PhoronixTestSuite/TestProfile/SupportedPlatforms"); // The OS software platforms supported by this test
-define("P_TEST_UNSUPPORTEDPLATFORMS", "PhoronixTestSuite/TestProfile/UnsupportedPlatforms"); // The OS software platforms NOT supported by this test
 define("P_TEST_EXDEP", "PhoronixTestSuite/TestProfile/ExternalDependencies"); // Test external dependencies
 define("P_TEST_CTPEXTENDS", "PhoronixTestSuite/TestProfile/Extends"); // Does this test profile extend another test? (Cascading Test Profiles)
 define("P_TEST_ROOTNEEDED", "PhoronixTestSuite/TestProfile/RequiresRoot"); // Is root access needed? If set to "TRUE"
 define("P_TEST_ENVIRONMENTSIZE", "PhoronixTestSuite/TestProfile/EnvironmentSize"); // Estimated size of capacity needed for testing environment (in MB)
+define("P_TEST_ENVIRONMENT_TESTING_SIZE", "PhoronixTestSuite/TestProfile/EnvironmentTestingSize"); // Estimated size of capacity needed for testing environment during testing (in MB)
 define("P_TEST_ESTIMATEDTIME", "PhoronixTestSuite/TestProfile/EstimatedLength"); // Estimated length of time it takes the test to complete (in minutes)
 define("P_TEST_PROJECTURL", "PhoronixTestSuite/TestProfile/ProjectURL"); // Estimated length of time it takes the test to complete (in minutes)
 define("P_TEST_SUPPORTS_COREVERSION", "PhoronixTestSuite/TestProfile/RequiresCoreVersion"); // If the test profile is bound to specific versions of the Phoronix Test Suite (pts-core)
 define("P_TEST_REFERENCE_SYSTEMS", "PhoronixTestSuite/TestProfile/ReferenceSystems"); // Phoronix Global IDs of reference systems for the test
+define("P_TEST_ALLOW_GLOBAL_UPLOADS", "PhoronixTestSuite/TestProfile/AllowGlobalUploads"); // Allow result uploads to Phoronix Global?
+define("P_TEST_AUTO_SAVE_RESULTS", "PhoronixTestSuite/TestProfile/AutoSaveResults"); // Automatically save test results?
 
 define("P_TEST_DEFAULTARGUMENTS", "PhoronixTestSuite/TestSettings/Default/Arguments"); // Default arguments
+define("P_TEST_DEFAULT_POST_ARGUMENTS", "PhoronixTestSuite/TestSettings/Default/PostArguments"); // Default post arguments
 define("P_TEST_POSSIBLEPATHS", "PhoronixTestSuite/TestSettings/Default/PossiblePaths"); // Possible paths
+define("P_TEST_ALLOW_CACHE_SHARE", "PhoronixTestSuite/TestSettings/Default/AllowCacheShare"); // Allow the result output to be cached and shared?
+define("P_TEST_MIN_LENGTH", "PhoronixTestSuite/TestSettings/Default/MinimumLength"); // The minimum length/run-time for results to be valid
+define("P_TEST_MAX_LENGTH", "PhoronixTestSuite/TestSettings/Default/MaximumLength"); // The maximum length/run-time for results to be valid
 define("P_TEST_OPTIONS_DISPLAYNAME", "PhoronixTestSuite/TestSettings/Option/DisplayName"); // The option names to show to the end-user
 define("P_TEST_OPTIONS_ARGPREFIX", "PhoronixTestSuite/TestSettings/Option/ArgumentPrefix"); // The option argument prefix
 define("P_TEST_OPTIONS_ARGPOSTFIX", "PhoronixTestSuite/TestSettings/Option/ArgumentPostfix"); // The option argument postfix
@@ -91,6 +97,12 @@ define("P_SUITE_TEST_NAME", "PhoronixTestSuite/RunTest/Test"); // Names of tests
 define("P_SUITE_TEST_MODE", "PhoronixTestSuite/RunTest/Mode"); // Modes (if available) for the test runs in suite
 define("P_SUITE_TEST_ARGUMENTS", "PhoronixTestSuite/RunTest/Arguments"); // Arguments of tests in suite
 define("P_SUITE_TEST_DESCRIPTION", "PhoronixTestSuite/RunTest/Description"); // Description of tests in suite
+define("P_SUITE_TEST_OVERRIDE_OPTIONS", "PhoronixTestSuite/RunTest/OverrideTestOptions"); // Settings to force/override in a test profile
+define("P_SUITE_TEST_WEIGHT", "PhoronixTestSuite/RunTest/Weight"); // This is only used on a weighted suite
+
+define("P_SUITE_WEIGHTED_BASE_FROM_TEST", "PhoronixTestSuite/WeightInformation/BaseFromTestProfile"); // Test profile to acquire needed information from for the weighted test
+define("P_SUITE_WEIGHTED_INITIAL_VALUE", "PhoronixTestSuite/WeightInformation/InitialValue"); // Initial value of the weight
+define("P_SUITE_WEIGHTED_FINAL_WEIGHT_EXPRESSION", "PhoronixTestSuite/WeightInformation/FinalWeight"); // Final weight expression
 
 //
 // TEST DOWNLOAD SPECIFICATION
@@ -120,6 +132,7 @@ define("P_EXDEP_PACKAGE_TITLE", "PhoronixTestSuite/ExternalDependencies/Package/
 define("P_EXDEP_PACKAGE_GENERIC", "PhoronixTestSuite/ExternalDependencies/Package/GenericName"); // Generic name of external dependency package
 define("P_EXDEP_PACKAGE_SPECIFIC", "PhoronixTestSuite/ExternalDependencies/Package/PackageName"); // Specific package name of external dependency package
 define("P_EXDEP_PACKAGE_FILECHECK", "PhoronixTestSuite/ExternalDependencies/Package/FileCheck"); // File check of external dependency package
+define("P_EXDEP_PACKAGE_ARCHSPECIFIC", "PhoronixTestSuite/ExternalDependencies/Package/ArchitectureSpecific"); // If the package is specific to a select architecture
 define("P_EXDEP_PACKAGE_POSSIBLENAMES", "PhoronixTestSuite/ExternalDependencies/Package/PossibleNames"); // Possible names of external dependency package
 
 //
@@ -166,13 +179,24 @@ define("P_RESULTS_RESULTS_GROUP_RAW", P_RESULTS_RESULTS_GROUP . "/" . S_RESULTS_
 define("P_OPTION_GLOBAL_USERNAME", "PhoronixTestSuite/GlobalDatabase/UserName"); // Phoronix Global user-name
 define("P_OPTION_GLOBAL_UPLOADKEY", "PhoronixTestSuite/GlobalDatabase/UploadKey"); // Phoronix Global upload key
 
-define("P_OPTION_LOAD_MODULES", "PhoronixTestSuite/Options/General/LoadModules"); // Modules to load by default
+define("P_OPTION_USAGE_REPORTING", "PhoronixTestSuite/Options/General/AnonymousUsageReporting"); // Anonymous usage reporting?
+define("P_OPTION_DEFAULT_BROWSER", "PhoronixTestSuite/Options/General/DefaultBrowser"); // Web browser to use to override the auto-detected browser
+define("P_OPTION_PHODEVI_CACHE", "PhoronixTestSuite/Options/General/UsePhodeviCache"); // Whether to use/create Phodevi smart cache in PTS
+define("P_OPTION_DISPLAY_MODE", "PhoronixTestSuite/Options/General/DefaultDisplayMode"); // The display mode to use by default
+define("P_OPTION_EXTRA_REFERENCE_SYSTEMS", "PhoronixTestSuite/Options/General/ReferenceSystems"); // Extra reference systems
+
+define("P_OPTION_LOAD_MODULES", "PhoronixTestSuite/Options/Modules/LoadModules"); // Modules to load by default
 
 define("P_OPTION_TEST_SLEEPTIME", "PhoronixTestSuite/Options/Testing/SleepTimeBetweenTests"); // Time in seconds to sleep between tests
-define("P_OPTION_LOG_VSYSDETAILS", "PhoronixTestSuite/Options/Testing/SaveSystemDetails"); // Log verbose system details?
-define("P_OPTION_LOG_BENCHMARKFILES", "PhoronixTestSuite/Options/Testing/SaveBenchmarkLogs"); // Save benchmark logs?
+define("P_OPTION_LOG_VSYSDETAILS", "PhoronixTestSuite/Options/Testing/SaveSystemLogs"); // Log verbose system details?
+define("P_OPTION_LOG_INSTALLATION", "PhoronixTestSuite/Options/Testing/SaveInstallationLogs"); // Save installation logs?
 define("P_OPTION_RESULTS_DIRECTORY", "PhoronixTestSuite/Options/Testing/ResultsDirectory"); // Results save directory
 
+define("P_OPTION_STATS_DYNAMIC_RUN_COUNT", "PhoronixTestSuite/Options/Statistics/DynamicRunCount"); // Increase run count if needed
+define("P_OPTION_STATS_NO_DYNAMIC_ON_LENGTH", "PhoronixTestSuite/Options/Statistics/LimitDynamicToTestLength"); // Only for tests that take less than XX time
+define("P_OPTION_STATS_STD_DEVIATION_THRESHOLD", "PhoronixTestSuite/Options/Statistics/StandardDeviationThreshold"); // The threshold for the standard deviation percent
+define("P_OPTION_STATS_EXPORT_RESULTS_TO", "PhoronixTestSuite/Options/Statistics/ExportResultsTo"); // Connect to an external script
+
 define("P_OPTION_TEST_REMOVEDOWNLOADS", "PhoronixTestSuite/Options/Installation/RemoveDownloadFiles"); // Remove downloaded files after test is installed
 define("P_OPTION_TEST_ENVIRONMENT", "PhoronixTestSuite/Options/Installation/EnvironmentDirectory"); // Results save directory
 define("P_OPTION_CACHE_DIRECTORY", "PhoronixTestSuite/Options/Installation/CacheDirectory"); // Directory for reading/writing to download cache
@@ -187,10 +211,16 @@ define("P_OPTION_BATCH_UPLOADRESULTS", "PhoronixTestSuite/Options/BatchMode/Uplo
 define("P_OPTION_BATCH_PROMPTIDENTIFIER", "PhoronixTestSuite/Options/BatchMode/PromptForTestIdentifier"); // Batch mode prompt for test identifier
 define("P_OPTION_BATCH_PROMPTDESCRIPTION", "PhoronixTestSuite/Options/BatchMode/PromptForTestDescription"); // Batch mode prompt for test description
 define("P_OPTION_BATCH_PROMPTSAVENAME", "PhoronixTestSuite/Options/BatchMode/PromptSaveName"); // Batch mode prompt for save results name
+define("P_OPTION_BATCH_TESTALLOPTIONS", "PhoronixTestSuite/Options/BatchMode/RunAllTestCombinations"); // Batch mode prompt to run all test options
 
-define("P_OPTION_TESTCORE_LASTVERSION", "PhoronixTestSuite/TestCore/LastRun/Version"); // Last version of the Phoronix Test Suite Run
-define("P_OPTION_TESTCORE_LASTTIME", "PhoronixTestSuite/TestCore/LastRun/Time"); // Last time the Phoronix Test Suite ran
-define("P_OPTION_USER_AGREEMENT", "PhoronixTestSuite/TestCore/UserInformation/AgreementCheckSum"); // PTS user agreement confirmation
+define("P_OPTION_NET_NO_NETWORK", "PhoronixTestSuite/Options/Networking/NoNetworkCommunication"); // Do not use the network at all
+define("P_OPTION_NET_TIMEOUT", "PhoronixTestSuite/Options/Networking/Timeout"); // Timeout after X seconds
+define("P_OPTION_NET_PROXY_ADDRESS", "PhoronixTestSuite/Options/Networking/ProxyAddress"); // IP / URL if using a proxy
+define("P_OPTION_NET_PROXY_PORT", "PhoronixTestSuite/Options/Networking/ProxyPort"); // Port if using a proxy
+
+define("P_OPTION_UI_SELECT_SUITESORTESTS", "PhoronixTestSuite/Options/UserInterface/Menus/SelectSuitesOrTests"); // Menu item for test or suites showing
+define("P_OPTION_UI_SELECT_DEPENDENCIES", "PhoronixTestSuite/Options/UserInterface/Menus/SelectDependencies"); // Menu item for "Dependencies" menu item
+define("P_OPTION_UI_SELECT_DOWNLOADS", "PhoronixTestSuite/Options/UserInterface/Menus/SelectDownloads"); // Menu item for "File Downloads" menu item
 
 //
 // MODULE CONFIGURATION SPECIFICATION
@@ -209,9 +239,11 @@ define("P_INSTALL_TEST_VERSION", "PhoronixTestSuite/TestInstallation/Environment
 define("P_INSTALL_TEST_CHECKSUM", "PhoronixTestSuite/TestInstallation/Environment/CheckSum"); // MD5 check-sum of executable
 define("P_INSTALL_TEST_SYSIDENTIFY", "PhoronixTestSuite/TestInstallation/Environment/SystemIdentifier"); // String identifying the system
 define("P_INSTALL_TEST_INSTALLTIME", "PhoronixTestSuite/TestInstallation/History/InstallTime"); // Time of test install
+define("P_INSTALL_TEST_INSTALLTIME_LENGTH", "PhoronixTestSuite/TestInstallation/History/InstallTimeLength"); // Length of time for the test to install (in seconds)
 define("P_INSTALL_TEST_LASTRUNTIME", "PhoronixTestSuite/TestInstallation/History/LastRunTime"); // Time the test last run
 define("P_INSTALL_TEST_TIMESRUN", "PhoronixTestSuite/TestInstallation/History/TimesRun"); // Time the test last run
 define("P_INSTALL_TEST_AVG_RUNTIME", "PhoronixTestSuite/TestInstallation/History/AverageRunTime"); // The average time (in Seconds) it takes to run the test
+define("P_INSTALL_TEST_LATEST_RUNTIME", "PhoronixTestSuite/TestInstallation/History/LatestRunTime"); // The time (in Seconds) it took to run the test during its last time
 
 //
 // GRAPH CONFIGURATION SPECIFICATION
@@ -222,6 +254,7 @@ define("P_GRAPH_SIZE_HEIGHT", "PhoronixTestSuite/Graphs/General/GraphHeight"); /
 define("P_GRAPH_RENDERER", "PhoronixTestSuite/Graphs/General/Renderer"); // Graph renderer
 define("P_GRAPH_MARKCOUNT", "PhoronixTestSuite/Graphs/General/NumberOfMarks"); // Graph number of marks
 define("P_GRAPH_WATERMARK", "PhoronixTestSuite/Graphs/General/Watermark"); // Graph watermark
+define("P_GRAPH_WATERMARK_URL", "PhoronixTestSuite/Graphs/General/WatermarkURL"); // Graph watermark URL
 define("P_GRAPH_BORDER", "PhoronixTestSuite/Graphs/General/Border"); // Render border around graph?
 
 define("P_GRAPH_COLOR_BACKGROUND", "PhoronixTestSuite/Graphs/Colors/Background"); // Graph color background
@@ -234,6 +267,7 @@ define("P_GRAPH_COLOR_TEXT", "PhoronixTestSuite/Graphs/Colors/Text"); // Graph c
 define("P_GRAPH_COLOR_BODYTEXT", "PhoronixTestSuite/Graphs/Colors/BodyText"); // Graph color body text
 define("P_GRAPH_COLOR_HEADERS", "PhoronixTestSuite/Graphs/Colors/Headers"); // Graph color text headers
 define("P_GRAPH_COLOR_MAINHEADERS", "PhoronixTestSuite/Graphs/Colors/MainHeaders"); // Graph color text main headers
+define("P_GRAPH_COLOR_ALERT", "PhoronixTestSuite/Graphs/Colors/Alert"); // Graph color of alerts
 
 define("P_GRAPH_FONT_TYPE", "PhoronixTestSuite/Graphs/Font/FontType"); // Graph font type
 define("P_GRAPH_FONT_SIZE_HEADERS", "PhoronixTestSuite/Graphs/Font/Headers"); // Graph font size for headers
