@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2008 - 2009, Phoronix Media
-	Copyright (C) 2008 - 2009, Michael Larabel
+	Copyright (C) 2008 - 2010, Phoronix Media
+	Copyright (C) 2008 - 2010, Michael Larabel
 	pts.php: Version information for the Phoronix Test Suite.
 
 	This program is free software; you can redistribute it and/or modify
@@ -21,8 +21,11 @@
 	along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
 
-define("PTS_VERSION", "1.8.1");
-define("PTS_CODENAME", "SELBU");
+//error_reporting(E_ERROR | E_STRICT);
+
+define("PTS_VERSION", "2.4.1");
+define("PTS_CORE_VERSION", 2410);
+define("PTS_CODENAME", "LENVIK");
 
 function pts_codename($full_string = false)
 {
@@ -30,5 +33,9 @@ function pts_codename($full_string = false)
 
 	return ($full_string ? "PhoronixTestSuite/" : "") . $codename;
 }
+function pts_title($show_both = false)
+{
+	return "Phoronix Test Suite" . (PTS_VERSION != null ? " v" . PTS_VERSION : null) . (PTS_CODENAME != null && (PTS_VERSION == null || $show_both ) ? " (" . ucwords(strtolower(PTS_CODENAME)) . ")" : null);
+}
 
 ?>
