@@ -4,7 +4,7 @@
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
 	Copyright (C) 2008, Phoronix Media
-	Copyright (C) 2004-2008, Michael Larabel
+	Copyright (C) 2008, Michael Larabel
 	graphics_override.php: Graphics AA/AF image quality setting override module
 
 	This program is free software; you can redistribute it and/or modify
@@ -24,7 +24,7 @@
 class graphics_event_checker extends pts_module_interface
 {
 	const module_name = "Graphics Event Checker";
-	const module_version = "0.1.0";
+	const module_version = "0.1.1";
 	const module_description = "This module checks a number of events prior to and and after running a test to make sure the graphics sub-system was not put in a sour or unintended state. For instance, it makes sure syncing to vBlank is not forced through the driver and that a graphics test had not ended prematurely where it left the resolution in an incorrect mode.";
 	const module_author = "Michael Larabel";
 
@@ -38,22 +38,22 @@ class graphics_event_checker extends pts_module_interface
 
 	public static function __pre_run_process()
 	{
-		if(count(read_xdpy_monitor_info()) > 1)
+		if(count(phodevi_parser::read_xdpy_monitor_info()) > 1)
 		{
 			echo "\nThe graphics_event_checker currently does not support multiple monitors.\n";
 			return PTS_MODULE_UNLOAD;
 		}
 
 		// Store the video resolution
-		self::$start_video_resolution = hw_gpu_xrandr_mode();
+		self::$start_video_resolution = phodevi::read_property("gpu", "screen-resolution");
 
 		if(IS_ATI_GRAPHICS)
 		{
-			$vsync_val = read_amd_pcsdb("AMDPCSROOT/SYSTEM/BUSID-*/OpenGL,VSyncControl"); // Check for vSync
+			$vsync_val = phodevi_parser::read_amd_pcsdb("AMDPCSROOT/SYSTEM/BUSID-*/OpenGL,VSyncControl"); // Check for vSync
 			if($vsync_val == "0x00000002" || $vsync_val == "0x00000003")
 				self::$start_vertical_sync = TRUE;
 
-			$catalyst_ai_val = read_amd_pcsdb("AMDPCSROOT/SYSTEM/BUSID-*/OpenGL,CatalystAI"); // Check for Catalyst AI
+			$catalyst_ai_val = phodevi_parser::read_amd_pcsdb("AMDPCSROOT/SYSTEM/BUSID-*/OpenGL,CatalystAI"); // Check for Catalyst AI
 			if($catalyst_ai_val == "0x00000001" || $catalyst_ai_val == "0x00000002")
 				echo "\nCatalyst AI is enabled, which will use driver-specific optimizations in some tests that may offer extra performance enhancements.\n";
 		}
@@ -61,7 +61,7 @@ class graphics_event_checker extends pts_module_interface
 		{
 			self::$error_pointer = self::nvidia_gpu_error_count(); // Set the error pointer
 
-			if(read_nvidia_extension("SyncToVBlank") == "1")
+			if(phodevi_parser::read_nvidia_extension("SyncToVBlank") == "1")
 				self::$start_vertical_sync = TRUE;
 		}
 
@@ -100,7 +100,7 @@ class graphics_event_checker extends pts_module_interface
 			if($current_error_position > self::$error_pointer && is_object($pts_test_result))
 			{
 				// GPU Error(s) Happened During The Test
-				$this_test = $pts_test_result->get_attribute("TEST_IDENTIFIER");
+				$this_test = $pts_test_result->get_test_profile()->get_identifier();
 				$this_error_count = $current_error_position - self::$error_pointer;
 
 				if(isset(self::$error_analysis[$this_test]))
@@ -114,7 +114,7 @@ class graphics_event_checker extends pts_module_interface
 	}
 	private static function check_video_resolution()
 	{
-		$current_res = hw_gpu_xrandr_mode();
+		$current_res = phodevi::read_property("gpu", "screen-resolution");
 
 		if($current_res != self::$start_video_resolution && self::$start_video_resolution != array(-1, -1))
 		{
@@ -126,12 +126,12 @@ class graphics_event_checker extends pts_module_interface
 			$reset_height = $reset[1];
 
 			echo "\nThe video resolution had changed during testing and it was not properly reset! Now resetting to $reset_width x $reset_height from $video_width x $video_height.\n";
-			hw_gpu_set_resolution($reset_width, $reset_height);
+			phodevi::set_property("gpu", "screen-resolution", array($reset_width, $reset_height));
 		}
 	}
 	protected static function nvidia_gpu_error_count()
 	{
-		$count = read_nvidia_extension("GPUErrors");
+		$count = phodevi_parser::read_nvidia_extension("GPUErrors");
 
 		if($count == null || !is_numeric($count))
 			$count = 0;
