@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2008 - 2009, Phoronix Media
-	Copyright (C) 2008 - 2009, Michael Larabel
+	Copyright (C) 2008 - 2010, Phoronix Media
+	Copyright (C) 2008 - 2010, Michael Larabel
 	bilde_renderer.php: The Phoronix Multi-Format "Bilde" Image Renderer
 
 	This program is free software; you can redistribute it and/or modify
@@ -23,29 +23,30 @@
 
 abstract class bilde_renderer
 {
+	// TODO: rework the entire bilde_renderer drawing API by PTS3, see michaellarabel for details. Right now it's getting a messy with the additions
 	var $renderer = "bilde_renderer";
-	var $image;
-	var $image_width = -1;
-	var $image_height = -1;
-	var $embed_identifiers = null;
+	protected $image;
+	protected $image_width = -1;
+	protected $image_height = -1;
+	protected $embed_identifiers = null;
+	protected $uid_count = 1;
 
 	abstract function __construct($width, $height, $embed_identifiers = ""); // create the object
-	abstract static function renderer_supported();
 
 	abstract function html_embed_code($file_name, $attributes = null, $is_xsl = false);
 	abstract function render_image($output_file = null, $quality = 100);
 	abstract function resize_image($width, $height);
 	abstract function destroy_image();
 
-	abstract function write_text_left($text_string, $font_type, $font_size, $font_color, $bound_x1, $bound_y1, $bound_x2, $bound_y2, $rotate_text = false);
-	abstract function write_text_right($text_string, $font_type, $font_size, $font_color, $bound_x1, $bound_y1, $bound_x2, $bound_y2, $rotate_text = false);
-	abstract function write_text_center($text_string, $font_type, $font_size, $font_color, $bound_x1, $bound_y1, $bound_x2, $bound_y2, $rotate_text = false);
+	abstract function write_text_left($text_string, $font_type, $font_size, $font_color, $bound_x1, $bound_y1, $bound_x2, $bound_y2, $rotate_text = false, $onclick = null);
+	abstract function write_text_right($text_string, $font_type, $font_size, $font_color, $bound_x1, $bound_y1, $bound_x2, $bound_y2, $rotate_text = false, $onclick = null);
+	abstract function write_text_center($text_string, $font_type, $font_size, $font_color, $bound_x1, $bound_y1, $bound_x2, $bound_y2, $rotate_text = false, $onclick = null);
 
 	abstract function draw_rectangle($x1, $y1, $width, $height, $background_color);
 	abstract function draw_rectangle_border($x1, $y1, $width, $height, $border_color);
 	abstract function draw_polygon($points, $body_color, $border_color = null, $border_width = 0);
-	abstract function draw_ellipse($center_x, $center_y, $width, $height, $body_color, $border_color = null, $border_width = 0);
-	abstract function draw_line($start_x, $start_y, $end_x, $end_y, $color, $line_width = 1);
+	abstract function draw_ellipse($center_x, $center_y, $width, $height, $body_color, $border_color = null, $border_width = 0, $default_hide = false);
+	abstract function draw_line($start_x, $start_y, $end_x, $end_y, $color, $line_width = 1, $title = null);
 
 	abstract function png_image_to_type($file);
 	abstract function jpg_image_to_type($file);
@@ -53,52 +54,106 @@ abstract class bilde_renderer
 	abstract function convert_hex_to_type($hex);
 	abstract function text_string_dimensions($string, $font_type, $font_size, $predefined_string = false);
 
+	//
+	// Meta functions that could be implemented within renderer-specifc code if available
+	//
+
+	public function draw_dashed_line($start_x, $start_y, $end_x, $end_y, $color, $line_width, $dash_length, $blank_length)
+	{
+		// TODO: does not currently support doing dashed lines on angles, below code can be cleaned up
+		if($start_y == $end_y)
+		{
+			$current_x = $start_x;
+			$next_x = $current_x + $dash_length;
+
+			while($next_x <= $end_x)
+			{
+				$this->draw_line($current_x, $start_y, $next_x, $start_y, $color, $line_width);
+
+				$current_x = $next_x + $blank_length;
+				$next_x = $current_x + $dash_length;
+			}
+
+			if($current_x < $end_x)
+			{
+				$this->draw_line($current_x, $start_y, $end_x, $start_y, $color, $line_width);
+			}
+		}
+	}
+	public function draw_poly_line($x_y_pair_array, $color, $line_width = 1)
+	{
+		$prev_pair = array_shift($x_y_pair_array);
+
+		foreach($x_y_pair_array as $x_y)
+		{
+			$this->draw_line($prev_pair[0], $prev_pair[1], $x_y[0], $x_y[1], $color, $line_width);
+			$prev_pair = $x_y;
+		}
+	}
+	public function request_uid()
+	{
+		return 'i_' . $this->uid_count++;
+	}
+	public function draw_rectangle_with_border($x1, $y1, $width, $height, $background_color, $border_color, $title = null)
+	{
+		$this->draw_rectangle($x1, $y1, $width, $height, $background_color);
+		$this->draw_rectangle_border($x1, $y1, $width, $height, $border_color);
+	}
+	public function draw_arrow($tip_x1, $tip_y1, $tail_x1, $tail_y1, $background_color, $border_color = null, $border_width = 0)
+	{
+		// TODO: Allow better support when arrow is running horizontally or on an angle instead of just vertical
+		$arrow_length = sqrt(pow(($tail_x1 - $tip_x1), 2) + pow(($tail_y1 - $tip_y1), 2));
+		$arrow_length_half = $arrow_length / 2;
+
+		$arrow_points = array(
+		$tip_x1, $tip_y1,
+		$tail_x1 + $arrow_length_half, $tail_y1,
+		$tail_x1 - $arrow_length_half, $tail_y1
+		);
+
+		$this->draw_polygon($arrow_points, $background_color, $border_color, $border_width);
+	}
+
+	public static function renderer_supported()
+	{
+		// This should be implemented by the different bilde renderers if the renderer is dependent upon some extensions or something else for the support
+		return true;
+	}
+
 	//
 	// Setup Functions
 	//
 
-	public function setup_renderer($requested_renderer, $width, $height, $embed_identifiers = "")
+	public static function setup_renderer($requested_renderer, $width, $height, $embed_identifiers = "")
 	{
 		bilde_renderer::setup_font_directory();
 		$available_renderers = array("PNG", "JPG", "GIF", "SWF", "SVG");
 		$fallback_renderer = "SVG";
-		$selected_renderer = null;
+		$selected_renderer = $fallback_renderer;
 
-		foreach($available_renderers as $this_renderer)
+		if(($this_renderer = getenv("BILDE_RENDERER")) != false || defined("BILDE_RENDERER") && ($this_renderer = BILDE_RENDERER))
 		{
-			if(getenv(strtoupper($this_renderer) . "_DEBUG") != false)
-			{
-				eval("\$is_supported = bilde_" . strtolower($this_renderer) . "_renderer::renderer_supported();");
+			eval("\$is_supported = bilde_" . strtolower($this_renderer) . "_renderer::renderer_supported();");
 
-				if($is_supported)
-				{
-					$requested_renderer = $this_renderer;
-					break;
-				}
+			if($is_supported)
+			{
+				eval("\$renderer = new bilde_" . strtolower($this_renderer) . "_renderer(\$width, \$height, \$embed_identifiers);");
+				return $renderer;
 			}
 		}
 
 		foreach($available_renderers as $this_renderer)
 		{
-			if($requested_renderer == $this_renderer)
+			eval("\$is_supported = bilde_" . strtolower($this_renderer) . "_renderer::renderer_supported();");
+
+			if($is_supported)
 			{
-				eval("\$is_supported = bilde_" . strtolower($this_renderer) . "_renderer::renderer_supported();");
-
-				if($is_supported)
-				{
-					$selected_renderer = $this_renderer;
-					break;
-				}
+				$selected_renderer = $this_renderer;
+				break;
 			}
 		}
 
-		if(!in_array($selected_renderer, $available_renderers))
-		{
-			$selected_renderer = $fallback_renderer;
-		}
-
 		eval("\$renderer = new bilde_" . strtolower($selected_renderer) . "_renderer(\$width, \$height, \$embed_identifiers);");
-
 		return $renderer;
 	}
 	public function render_to_file($output_file = null, $quality = 100)
@@ -111,7 +166,7 @@ abstract class bilde_renderer
 	// Generic Functions
 	//
 
-	public function setup_font_directory()
+	public static function setup_font_directory()
 	{
 		// Setup directory for TTF Fonts
 		if(getenv("GDFONTPATH") == false)
@@ -134,25 +189,42 @@ abstract class bilde_renderer
 			}
 		}
 	}
-	public function find_default_ttf_font()
+	public static function find_default_ttf_font($find_font = null)
 	{
 		if(!defined("BILDE_DEFAULT_FONT"))
 		{
-			$default_font = false;
-			$possible_fonts = array(
-			"/usr/share/fonts/truetype/ttf-dejavu/DejaVuSans.ttf",
-			"/usr/share/fonts/truetype/freefont/FreeSans.ttf",
-			"/usr/share/fonts/truetype/ttf-bitstream-vera/Vera.ttf",
-			"/usr/share/fonts/dejavu/DejaVuSans.ttf",
-			"/usr/share/fonts/liberation/LiberationSans-Regular.ttf"
-			);
-
-			foreach($possible_fonts as $font_file)
+			if(is_readable($find_font))
 			{
-				if(is_file($font_file))
+				$default_font = $find_font;
+			}
+			else if(ini_get("open_basedir"))
+			{
+				$default_font = false;
+			}
+			else
+			{
+				$default_font = false;
+				$possible_fonts = array(
+				"/usr/share/fonts/truetype/ttf-dejavu/DejaVuSans.ttf",
+				"/usr/share/fonts/truetype/freefont/FreeSans.ttf",
+				"/usr/share/fonts/truetype/ttf-bitstream-vera/Vera.ttf",
+				"/usr/share/fonts/dejavu/DejaVuSans.ttf",
+				"/usr/share/fonts/liberation/LiberationSans-Regular.ttf",
+				"/usr/share/fonts/truetype/DejaVuSans.ttf",
+				"/usr/share/fonts/truetype/LiberationSans-Regular.ttf",
+				"/usr/share/fonts/TTF/dejavu/DejaVuSans.ttf",
+				"/usr/share/fonts/TTF/liberation/LiberationSans-Regular.ttf",
+				"/usr/X11/lib/X11/fonts/TrueType/arphic/uming.ttf",
+				"/usr/local/lib/X11/fonts/bitstream-vera/Vera.ttf"
+				);
+
+				foreach($possible_fonts as $font_file)
 				{
-					$default_font = $font_file;
-					break;
+					if(is_readable($font_file))
+					{
+						$default_font = $font_file;
+						break;
+					}
 				}
 			}
 
@@ -195,18 +267,18 @@ abstract class bilde_renderer
 
 		return $return_type;
 	}
-	public function soft_text_string_dimensions($text_string, $font_type, $font_size, $predefined_string = false)
+	public static function soft_text_string_dimensions($text_string, $font_type, $font_size, $predefined_string = false)
 	{
 		bilde_renderer::setup_font_directory();
 
-		if(function_exists("imagettfbbox"))
+		if(function_exists("imagettfbbox") && $font_type != false)
 		{
 			$box_array = imagettfbbox($font_size, 0, $font_type, $text_string);
 			$box_width = $box_array[4] - $box_array[6];
 
 			if($predefined_string)
 			{
-				$box_array = imagettfbbox($font_size, 0, $font_type, "AZ@![]()@|_qy");
+				$box_array = imagettfbbox($font_size, 0, $font_type, "JAZ@![]()@|_qy");
 			}
 
 			$box_height = $box_array[1] - $box_array[7];
@@ -221,20 +293,6 @@ abstract class bilde_renderer
 		// Width x Height
 		return array($box_width, $box_height);
 	}
-	public function draw_arrow($tip_x1, $tip_y1, $tail_x1, $tail_y1, $background_color)
-	{
-		// TODO: Allow better support when arrow is running horizontally or on an angle instead of just vertical
-		$arrow_length = sqrt(pow(($tail_x1 - $tip_x1), 2) + pow(($tail_y1 - $tip_y1), 2));
-		$arrow_length_half = $arrow_length / 2;
-
-		$arrow_points = array(
-		$tip_x1, $tip_y1,
-		$tail_x1 + $arrow_length_half, $tail_y1,
-		$tail_x1 - $arrow_length_half, $tail_y1
-		);
-
-		$this->draw_polygon($arrow_points, $background_color);
-	}
 	protected function text_string_width($text_string, $font_type, $font_size)
 	{
 		$dimensions = $this->text_string_dimensions($text_string, $font_type, $font_size);
