@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2008, Phoronix Media
-	Copyright (C) 2008, Michael Larabel
+	Copyright (C) 2008 - 2010, Phoronix Media
+	Copyright (C) 2008 - 2010, Michael Larabel
 	pts_CustomGraph.php: A pass-through extension extending pts_Graph that over-rides attributes with the PTS user configuration options.
 
 	This program is free software; you can redistribute it and/or modify
@@ -23,36 +23,21 @@
 
 class pts_CustomGraph extends pts_Graph
 {
-	function __construct($Title, $SubTitle, $YTitle)
+	function __construct(&$result_object)
 	{
-		if(PTS_MODE == "CLIENT")
-		{
-			$this->setup_custom_values();
-		}
-
-		parent::__construct($Title, $SubTitle, $YTitle);
+		$this->setup_custom_values();
+		parent::__construct($result_object);
 	}
 	private function setup_custom_values()
 	{
-		if(is_file(PTS_USER_DIR . "graph-config.xml"))
+		if(!(PTS_MODE == "CLIENT" || (defined("PTS_LIB_GRAPH_CONFIG_XML") && is_file(PTS_LIB_GRAPH_CONFIG_XML))))
 		{
-			$file = file_get_contents(PTS_USER_DIR . "graph-config.xml");
-		}
-		else
-		{
-			$file = "";
+			// setting custom values through pts_CustomGraph is only supported when called from client OR
+			// when running as a library, but with a file of the config XML specified
+			return;
 		}
 
-		$read_config = new tandem_XmlReader($file);
-
-		$font_xml = pts_read_graph_config(P_GRAPH_FONT_TYPE, null, $read_config);
-		$font_type = basename($font_xml);
-
-		if($font_xml != $font_type && !defined("CUSTOM_FONT_DIR"))
-		{
-			$font_path = substr($font_xml, 0, 0 - (strlen($font_type)));
-			define("CUSTOM_FONT_DIR", $font_path);
-		}
+		$read_config = new pts_graph_config_tandem_XmlReader();
 
 		$this->graph_attr_width = pts_read_graph_config(P_GRAPH_SIZE_WIDTH, null, $read_config); // Graph width
 		$this->graph_attr_height = pts_read_graph_config(P_GRAPH_SIZE_HEIGHT, null, $read_config); // Graph height
@@ -68,12 +53,14 @@ class pts_CustomGraph extends pts_Graph
 		$this->graph_color_body = pts_read_graph_config(P_GRAPH_COLOR_BODY, null, $read_config); // Color of graph body
 		$this->graph_color_body_text = pts_read_graph_config(P_GRAPH_COLOR_BODYTEXT, null, $read_config); // Color of graph body text
 		$this->graph_color_body_light = pts_read_graph_config(P_GRAPH_COLOR_ALTERNATE, null, $read_config); // Color of the border around graph bars (if doing a bar graph)
+		$this->graph_color_alert = pts_read_graph_config(P_GRAPH_COLOR_ALERT, null, $read_config); // Color for alerts
 
 		$this->graph_color_paint = explode(", ", pts_read_graph_config(P_GRAPH_COLOR_PAINT, null, $read_config)); // Colors to use for the bars / lines, one color for each key
 
 		// Text
 		$this->graph_watermark_text = pts_read_graph_config(P_GRAPH_WATERMARK, null, $read_config); // watermark
-		$this->graph_font = $font_type; // TTF file name
+		$this->graph_watermark_url = pts_read_graph_config(P_GRAPH_WATERMARK_URL, null, $read_config); // watermark URL
+		$this->graph_font = pts_read_graph_config(P_GRAPH_FONT_TYPE, null, $read_config);  // TTF file name
 		$this->graph_font_size_heading = pts_read_graph_config(P_GRAPH_FONT_SIZE_HEADERS, null, $read_config); // Font size of headings
 		$this->graph_font_size_bars = pts_read_graph_config(P_GRAPH_FONT_SIZE_TEXT, null, $read_config); // Font size for text on the bars/objects
 		$this->graph_font_size_identifiers = pts_read_graph_config(P_GRAPH_FONT_SIZE_IDENTIFIERS, null, $read_config); // Font size of identifiers
