@@ -26,11 +26,7 @@ class pts_module
 	public static function save_dir()
 	{
 		$prefix_dir = PTS_USER_DIR . "module-files/";
-
-		if(!is_dir($prefix_dir))
-		{
-			mkdir($prefix_dir);
-		}
+		pts_mkdir($prefix_dir);
 
 		return $prefix_dir . str_replace("_", "-", self::module_name()) . "/";
 	}
@@ -39,7 +35,7 @@ class pts_module
 		$module_name = self::module_name();
 		$is_setup = true;
 
-		$module_setup_options = pts_php_module_call($module_name, "module_setup");
+		$module_setup_options = pts_module_call($module_name, "module_setup");
 
 		foreach($module_setup_options as $option)
 		{
@@ -99,10 +95,7 @@ class pts_module
 
 		$save_base_dir = self::save_dir();
 
-		if(!is_dir($save_base_dir))
-		{
-			mkdir($save_base_dir);
-		}
+		pts_mkdir($save_base_dir);
 
 		if(($extra_dir = dirname($file)) != "." && !is_dir($save_base_dir . $extra_dir))
 		{
@@ -133,7 +126,7 @@ class pts_module
 	{
 		$file = self::save_dir() . $file;
 
-		return (is_file($file) ? file_get_contents($file) : false);		
+		return is_file($file) ? file_get_contents($file) : false;	
 	}
 	public static function is_file($file)
 	{
@@ -150,13 +143,9 @@ class pts_module
 	public static function copy_file($from_file, $to_file)
 	{
 		// Copy a file for a module
-
 		$save_base_dir = self::save_dir();
 
-		if(!is_dir($save_base_dir))
-		{
-			mkdir($save_base_dir);
-		}
+		pts_mkdir($save_base_dir);
 
 		if(($extra_dir = dirname($to_file)) != "." && !is_dir($save_base_dir . $extra_dir))
 		{
@@ -179,7 +168,7 @@ class pts_module
 	}
 	public static function pts_timed_function($time, $function)
 	{
-		if($time <= 5 || $time > 300)
+		if($time < 3 || $time > 300)
 		{
 			return;
 		}
@@ -200,7 +189,7 @@ class pts_module
 					$start_id = pts_unique_runtime_identifier();
 					while(!pts_is_assignment("PTS_TESTING_DONE") && ($start_id == pts_unique_runtime_identifier() || $start_id == PTS_INIT_TIME) && is_file(PTS_USER_LOCK) && $loop_continue)
 					{
-						eval(self::module_name() . "::" . $function . "();"); // TODO: This can be cleaned up once PHP 5.3.0+ is out there and adopted
+						eval(self::module_name() . "::" . $function . "();");
 
 						if($time > 0)
 						{
@@ -224,7 +213,7 @@ class pts_module
 	{
 		$module_name = "unknown";
 
-		if(($current = pts_module_current()) != false)
+		if(($current = pts_module_manager::get_current_module()) != null)
 		{
 			$module_name = $current;
 		}
