@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2008, Phoronix Media
-	Copyright (C) 2008, Michael Larabel
+	Copyright (C) 2008 - 2009, Phoronix Media
+	Copyright (C) 2008 - 2009, Michael Larabel
 	pts_test_option: An object used for storing a test option and its possible values
 
 	This program is free software; you can redistribute it and/or modify
@@ -23,12 +23,12 @@
 
 class pts_test_option
 {
-	var $identifier = "";
-	var $option_name = "";
-	var $prefix = "";
-	var $postfix = "";
-	var $default_entry = -1;
-	var $options = array();
+	private $identifier = "";
+	private $option_name = "";
+	private $prefix = "";
+	private $postfix = "";
+	private $default_entry = -1;
+	private $options = array();
 
 	public function __construct($identifier, $option)
 	{
@@ -68,15 +68,8 @@ class pts_test_option
 		return $this->postfix;
 	}
 	public function get_option_default()
-	{
-		$default = $this->default_entry;
-
-		if($default == -1)
-		{
-			$default = $this->option_count() - 1;
-		}
-
-		return $default;
+	{		
+		return $this->default_entry == -1 ? $this->option_count() - 1 : $this->default_entry;
 	}
 	public function add_option($name, $value)
 	{
@@ -87,17 +80,19 @@ class pts_test_option
 		$names = array();
 
 		for($i = 0; $i < $this->option_count(); $i++)
+		{
 			array_push($names, $this->get_option_name($i));
+		}
 
 		return $names;
 	}
 	public function get_option_name($index)
 	{
-		return $this->options[$index][0];
+		return isset($this->options[$index][0]) ? $this->options[$index][0] : null;
 	}
 	public function get_option_value($index)
 	{
-		return $this->options[$index][1];
+		return isset($this->options[$index][1]) ? $this->options[$index][1] : null;
 	}
 	public function option_count()
 	{
@@ -107,6 +102,12 @@ class pts_test_option
 	{
 		return $this->get_option_prefix() . $input . $this->get_option_postfix();
 	}
+	public function format_option_display_from_input($input)
+	{
+		$name = $this->get_name();
+
+		return $name != null && $input != null ? $name . ": " . $input : null;
+	}
 	public function format_option_value_from_select($select_pos)
 	{
 		$input = $this->get_option_value($select_pos);
@@ -119,10 +120,10 @@ class pts_test_option
 
 		if(($cut_point = strpos($display_name, "(")) > 1 && strpos($display_name, ")") > $cut_point)
 		{
-			$display_name = substr($display_name, 0, $cut_point);
+			$display_name = trim(substr($display_name, 0, $cut_point));
 		}
 
-		return $this->get_name() . ": " . $display_name;
+		return $this->format_option_display_from_input($display_name);
 	}
 	public function is_valid_select_choice($select_pos)
 	{
@@ -130,7 +131,7 @@ class pts_test_option
 
 		if($select_pos > 0 && $select_pos <= $this->option_count())
 		{
-			$valid = ($select_pos - 1);
+			$valid = $select_pos - 1;
 		}
 		else if(in_array($select_pos, $this->get_all_option_names()))
 		{
@@ -148,6 +149,38 @@ class pts_test_option
 
 		return $valid;
 	}
+	public function parse_selection_choice_input($input, $use_default_on_empty = true)
+	{
+		$return_keys = array();
+
+		foreach(pts_trim_explode(",", $input) as $input_choice)
+		{
+			if($input_choice == ($this->option_count() + 1) || $input_choice == "Test All Options")
+			{
+				// Add all options
+				foreach(array_keys($this->options) as $i)
+				{
+					array_push($return_keys, $i);
+				}
+				break;
+			}
+			else if(($c = $this->is_valid_select_choice($input_choice)) !== false)
+			{
+				array_push($return_keys, $c);
+			}
+		}
+
+		$return_keys = array_unique($return_keys);
+		sort($return_keys);
+
+		if($use_default_on_empty && count($return_keys) == 0)
+		{
+			// Use the default as no valid options were presented
+			array_push($return_keys, $this->get_option_default());
+		}
+
+		return $return_keys;
+	}
 }
 
 ?>
