@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2008 - 2009, Phoronix Media
-	Copyright (C) 2008 - 2009, Michael Larabel
+	Copyright (C) 2008 - 2010, Phoronix Media
+	Copyright (C) 2008 - 2010, Michael Larabel
 	pts_config_tandem_XmlReader.php: The XML reading object for the Phoronix Test Suite for the user config
 
 	Additional Notes: A very simple XML parser with a few extras... Does not currently support attributes on tags, etc.
@@ -26,7 +26,7 @@
 
 class pts_config_tandem_XmlReader extends tandem_XmlReader
 {
-	var $override_values;
+	protected $override_values;
 
 	public function __construct($new_values = null)
 	{
@@ -34,29 +34,49 @@ class pts_config_tandem_XmlReader extends tandem_XmlReader
 		{
 			$file = file_get_contents(PTS_USER_DIR . "user-config.xml");
 		}
-		else if(is_file(ETC_DIR . "user-config-template.xml"))
+		else if(is_file(STATIC_DIR . "user-config-template.xml"))
 		{
-			$file = file_get_contents(ETC_DIR . "user-config-template.xml");
+			$file = file_get_contents(STATIC_DIR . "user-config-template.xml");
 		}
 		else
 		{
-			$file = "";
+			$file = null;
 		}
 
 		$this->override_values = (is_array($new_values) ? $new_values : false);
 
-		parent::__construct($file, true);
+		parent::__construct($file);
 	}
-	function getValue($xml_path, $xml_tag = null, $xml_match = null, $cache_tag = true, $is_fallback_call = false)
+	function handleXmlZeroTagFallback($xml_tag)
 	{
-		if($this->override_values != false && isset($this->override_values[$xml_path]))
+		switch($xml_tag)
 		{
-			return $this->override_values[$xml_path];
+			case P_OPTION_LOG_VSYSDETAILS:
+				// SaveSystemDetails changed to SaveSystemLogs in Phoronix Test Suite 2.2
+				$fallback = $this->getXMLValue("PhoronixTestSuite/Options/Testing/SaveSystemDetails");
+				break;
+			default:
+				$fallback = $this->tag_fallback_value;
+				break;
 		}
-		else
+
+		return $fallback;
+	}
+	function getValue($xml_path, $xml_tag = null, $xml_match = null, $is_fallback_call = false)
+	{
+		if($this->override_values != false)
 		{
-			return parent::getValue($xml_path, $xml_tag, $xml_match, $cache_tag, $is_fallback_call);
+			if(isset($this->override_values[$xml_path]))
+			{
+				return $this->override_values[$xml_path];
+			}
+			else if(isset($this->override_values[($bn = basename($xml_path))]))
+			{
+				return $this->override_values[$bn];
+			}
 		}
+
+		return parent::getValue($xml_path, $xml_tag, $xml_match, $is_fallback_call);
 	}
 }
 ?>
