@@ -8,7 +8,6 @@
 	tandem_XmlReader.php: The XML reading object for the Phoronix Test Suite.
 
 	Additional Notes: A very simple XML parser with a few extras... Does not currently support attributes on tags, etc.
-	A work in progress. This was originally designed for just some select needs in the past. No XML validation is done with this parser, etc.
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -26,57 +25,19 @@
 
 class tandem_XmlReader
 {
-	var $xml_data = ""; // XML contents
-	var $xml_file_time = null; // File modification time
-	var $xml_file_name = null; // File name
+	protected $xml_data = null; // XML contents
+	protected $tag_fallback_value = null; // Fallback value if tag is not present
 
-	var $xml_cache_file = false; // Cache the entire XML file being parsed?
-	var $xml_cache_tags = true; // Cache the tags that are being called?
-
-	var $tag_fallback_value = null; // Fallback value if tag is not present
-
-	static $tag_cache = null; // The cache for the tag cache
-	static $file_cache = null; // The cache for the file cache
-
-	function __construct($read_xml, $cache_support = true)
+	function __construct($read_xml)
 	{
-		$remote_file = isset($read_xml[8]) && substr($read_xml, 0, 7) == "http://";
-
-		if(is_readable($read_xml) || $remote_file)
+		if(substr(trim($read_xml), 0, 1) != '<' && (is_readable($read_xml) || (strpos($read_xml, "://") !== false && strpos($read_xml, "://") < strpos($read_xml, "\n"))))
 		{
-			if($cache_support && !$remote_file)
-			{
-				$this->xml_cache_file = false;
-				$this->xml_cache_tags = false;
-			}
-
-			// If you are going to be banging XML files hard through the course of the script, you will want to flush the PHP file cache
-			// clearstatcache();
-
-			$this->xml_file_time = ($remote_file ? null : filemtime($read_xml));
-			$this->xml_file_name = $read_xml;
-
-			if($this->xml_cache_file && isset(self::$file_cache[$this->xml_file_name][$this->xml_file_time]))
-			{
-				$this->xml_data = self::$file_cache[$this->xml_file_name][$this->xml_file_time];
-			}
-
-			if(empty($this->xml_data))
-			{
-				$this->xml_data = file_get_contents($read_xml);
-
-				if($this->xml_cache_file)
-				{
-					self::$file_cache[$this->xml_file_name][$this->xml_file_time] = $this->xml_data;
-				}
-			}
-		}
-		else
-		{
-			$this->xml_cache_file = false;
-			$this->xml_cache_tags = false;
-			$this->xml_data = $read_xml;
+			$read_xml = file_get_contents($read_xml);
 		}
+
+		$read_xml = str_replace(array("\n", "\t"), null, $read_xml);
+
+		$this->xml_data = $read_xml;
 	}
 	function getStatement($statement)
 	{
@@ -108,15 +69,15 @@ class tandem_XmlReader
 
 		return $return_r;
 	}
-	function getXMLValue($xml_tag)
+	function getXMLValue($xml_tag, $fallback_value = false)
 	{
-		return $this->getValue($xml_tag);
+		return ($v = $this->getValue($xml_tag)) != false ? $v : $fallback_value;
 	}
 	function isDefined($xml_tag)
 	{
 		return $this->getValue($xml_tag) != null;
 	}
-	function getValue($xml_path, $xml_tag = null, $xml_match = null, $cache_tag = true, $is_fallback_call = false)
+	function getValue($xml_path, $xml_tag = null, $xml_match = null, $is_fallback_call = false)
 	{
 		if($xml_tag == null)
 		{
@@ -127,25 +88,13 @@ class tandem_XmlReader
 			$xml_match = $this->xml_data;
 		}
 
-		if($this->xml_cache_tags && $cache_tag && isset(self::$tag_cache[$this->xml_file_name][$this->xml_file_time][$xml_tag]))
+		foreach(explode('/', $xml_tag) as $xml_step)
 		{
-			$xml_match = self::$tag_cache[$this->xml_file_name][$this->xml_file_time][$xml_tag];
-		}
-		else
-		{
-			foreach(explode("/", $xml_tag) as $xml_step)
-			{
-				$xml_match = $this->parseXMLString($xml_step, $xml_match, false);
+			$xml_match = $this->parseXMLString($xml_step, $xml_match, false);
 
-				if($xml_match == false)
-				{
-					$xml_match = (!$is_fallback_call ? $this->handleXmlZeroTagFallback($xml_path) : $this->tag_fallback_value);
-				}
-			}
-
-			if($this->xml_cache_tags && $cache_tag)
+			if($xml_match == false)
 			{
-				self::$tag_cache[$this->xml_file_name][$this->xml_file_time][$xml_tag] = $xml_match;
+				$xml_match = !$is_fallback_call ? $this->handleXmlZeroTagFallback($xml_path) : $this->tag_fallback_value;
 			}
 		}
 
@@ -154,43 +103,51 @@ class tandem_XmlReader
 	function parseXMLString($xml_tag, $to_parse, $multi_search = true)
 	{
 		$return = false;
-		$temp_r = array();
-		$temp = $to_parse;
 
 		$open_tag = "<" . $xml_tag . ">";
 		$close_tag  = "</" . $xml_tag . ">";
 		$open_tag_length = strlen($open_tag);
 		$close_tag_length = strlen($close_tag);
 
-		do
+		if($multi_search)
 		{
-			$return = null;
+			$temp = $to_parse;
+			$return = array();
 
-			if(($start = strpos($temp, $open_tag)) !== false)
+			do
 			{
-				$temp = substr($temp, $start + $open_tag_length);
+				$found = false;
 
-				if(($end = strpos($temp, $close_tag)) !== false)
+				if(($start = strpos($temp, $open_tag)) !== false)
 				{
-					$return = substr($temp, 0, $end);
-					$temp = substr($temp, strlen($return) + $close_tag_length);
+					$temp = substr($temp, $start + $open_tag_length);
+
+					if(($end = strpos($temp, $close_tag)) !== false)
+					{
+						$contents = substr($temp, 0, $end);
+						$temp = substr($temp, strlen($contents) + $close_tag_length);
+						array_push($return, $contents);
+						$found = true;
+					}
 				}
 			}
+			while($found);
 
-			if($return != null)
+			if(!isset($return[0]))
 			{
-				array_push($temp_r, $return);
+				$return = false;
 			}
 		}
-		while($return != null && $multi_search);
-
-		if(count($temp_r) > 0)
+		else
 		{
-			$return = $temp_r;
-
-			if($multi_search == false)
+			if(($start = strpos($to_parse, $open_tag)) !== false)
 			{
-				$return = $return[0];
+				$to_parse = substr($to_parse, $start + $open_tag_length);
+
+				if(($end = strpos($to_parse, $close_tag)) !== false)
+				{
+					$return = substr($to_parse, 0, $end);
+				}
 			}
 		}
 
@@ -244,60 +201,33 @@ class tandem_XmlReader
 	}
 	function getArrayValues($xml_tag, $xml_match)
 	{
+		$return_r = array();
 		$xml_steps = explode("/", $xml_tag);
 		$xml_steps_count = count($xml_steps);
 		$this_xml = $xml_match;
 
 		for($i = 0; $i < ($xml_steps_count - 2); $i++)
 		{
-			$this_xml = $this->getValue($xml_tag, $xml_steps[$i], $this_xml, false);
+			$this_xml = $this->getValue($xml_tag, $xml_steps[$i], $this_xml);
 		}
 
 		$xml_matches = $this->parseXMLString($xml_steps[($xml_steps_count - 2)], $this_xml);
-		$xml_matches_count = count($xml_matches);
+		$end_tag = end($xml_steps);
 
-		$return_r = array();
-		$extraction_tags = explode(",", end($xml_steps));
-		$extraction_tags_count = count($extraction_tags);
-
-		for($i = 0; $i < $xml_matches_count; $i++)
+		if($xml_matches != false)
 		{
-			if($extraction_tags_count == 1)
+			foreach($xml_matches as $match)
 			{
-				$this_item = $this->getValue($xml_tag, $extraction_tags[0], $xml_matches[$i], false);
-				array_push($return_r, $this_item);
-			}
-			else
-			{
-				if($i == 0)
-				{
-					foreach($extraction_tags as $extract)
-					{
-						$return_r[$extract] = array();
-					}
-				}
+				$this_item = $this->getValue($xml_tag, $end_tag, $match);
 
-				foreach($extraction_tags as $extract)
-				{
-					$this_item = $this->getValue($xml_tag, $extract, $xml_matches[$i], false);
-					array_push($return_r[$extract], $this_item);
-				}
+				//if($this_item != false)
+				//{
+					array_push($return_r, $this_item);
+				//}
 			}
 		}
+
 		return $return_r;
 	}
-	function setFileCaching($do_cache)
-	{
-		$this->xml_cache_file = ($do_cache == true);
-	}
-	function setTagCaching($do_cache)
-	{
-		$this->xml_cache_tags = ($do_cache == true);
-	}
-	function setCaching($do_cache)
-	{
-		$this->setFileCaching($do_cache);
-		$this->setTagCaching($do_cache);
-	}
 }
 ?>
