@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2008 - 2009, Phoronix Media
-	Copyright (C) 2008 - 2009, Michael Larabel
+	Copyright (C) 2008 - 2010, Phoronix Media
+	Copyright (C) 2008 - 2010, Michael Larabel
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -53,6 +53,27 @@ class build_suite implements pts_option_interface
 		$xml_writer->addXmlObject(P_SUITE_DESCRIPTION, 0, $suite_description);
 		$write_position = 1;
 
+		foreach($r as $test_object)
+		{
+			if(pts_is_test($test_object))
+			{
+				list($args, $description) = pts_prompt_test_options($test_object);
+
+				for($i = 0; $i < count($args); $i++)
+				{
+					$xml_writer->addXmlObject(P_SUITE_TEST_NAME, $write_position, $test_object);
+					$xml_writer->addXmlObject(P_SUITE_TEST_ARGUMENTS, $write_position, $args[$i]);
+					$xml_writer->addXmlObject(P_SUITE_TEST_DESCRIPTION, $write_position, $description[$i]);
+					$write_position++;
+				}
+			}
+			else if(pts_is_suite($test_object))
+			{
+				$xml_writer->addXmlObject(P_SUITE_TEST_NAME, $write_position, $test_object);
+				$write_position++;
+			}
+		}
+
 		do
 		{
 			switch($input_option)
@@ -60,16 +81,15 @@ class build_suite implements pts_option_interface
 				case "Add Test":
 					$test_to_add = pts_text_select_menu("Enter test name", $possible_tests);
 
-					$option_output = pts_prompt_test_options($test_to_add);
+					list($args, $description) = pts_prompt_test_options($test_to_add);
 
-					$xml_writer->addXmlObject(P_SUITE_TEST_NAME, $write_position, $test_to_add);
-
-					if(!empty($option_output[0]) && !empty($option_output[0]))
+					for($i = 0; $i < count($args); $i++)
 					{
-						$xml_writer->addXmlObject(P_SUITE_TEST_ARGUMENTS, $write_position, $option_output[0]);
-						$xml_writer->addXmlObject(P_SUITE_TEST_DESCRIPTION, $write_position, $option_output[1]);
+						$xml_writer->addXmlObject(P_SUITE_TEST_NAME, $write_position, $test_to_add);
+						$xml_writer->addXmlObject(P_SUITE_TEST_ARGUMENTS, $write_position, $args[$i]);
+						$xml_writer->addXmlObject(P_SUITE_TEST_DESCRIPTION, $write_position, $description[$i]);
+						$write_position++;
 					}
-					$write_position++;
 					break;
 				case "Add Sub-Suite":
 					$suite_to_add = pts_text_select_menu("Enter test suite", $possible_suites);
@@ -97,7 +117,7 @@ class build_suite implements pts_option_interface
 		}
 		$save_to = XML_SUITE_LOCAL_DIR . $suite_identifier . ".xml";
 
-		$fp = file_put_contents($save_to, $xml_writer->getXML());
+		$fp = $xml_writer->saveXMLFile($save_to);
 
 		if($fp != false)
 		{
