@@ -26,15 +26,14 @@ class global_login implements pts_option_interface
 	{
 		echo "\nIf you have not already registered for your free Phoronix Global account, you can do so at http://global.phoronix-test-suite.com/\n\nOnce you have registered your account and clicked the link within the verification email, enter your log-in information below.\n\n";
 		echo "User-Name: ";
-		$username = trim(fgets(STDIN));
+		$username = pts_read_user_input();
 		echo "Password: ";
-		$password = md5(trim(fgets(STDIN)));
-		$uploadkey = @file_get_contents("http://www.phoronix-test-suite.com/global/account-verify.php?user_name=" . $username . "&user_md5_pass=" . $password);
+		$password = md5(pts_read_user_input());
+		$global_success = pts_global_setup_account($username, $password);
 
-		if(!empty($uploadkey))
+		if($global_success)
 		{
-			pts_user_config_init(array(P_OPTION_GLOBAL_USERNAME => $username, P_OPTION_GLOBAL_UPLOADKEY => $uploadkey));
-			echo "\nAccount: " . $uploadkey . "\nAccount information written to user-config.xml.\n\n";
+			echo "\nPhoronix Global Account Setup.\nAccount information written to ~/.phoronix-test-suite/user-config.xml.\n\n";
 		}
 		else
 		{
