@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2008, Phoronix Media
-	Copyright (C) 2008, Michael Larabel
+	Copyright (C) 2008 - 2009, Phoronix Media
+	Copyright (C) 2008 - 2009, Michael Larabel
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -24,19 +24,7 @@ class install_all_dependencies implements pts_option_interface
 {
 	public static function run($r)
 	{
-		pts_load_function_set("install");
-
-		$packages_to_install = array();
-		pts_package_generic_to_distro_name($packages_to_install, "all");
-
-		if(empty($packages_to_install) || count($packages_to_install) == 0)
-		{
-			echo pts_string_header("No packages found. Your operating system may not support this feature.\nSeek support from http://www.phoronix-test-suite.com/.");
-		}
-		else
-		{
-			pts_install_packages_on_distribution_process($packages_to_install);
-		}
+		pts_run_option_next("install_dependencies", "all");
 	}
 }
 
