@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2008, Phoronix Media
-	Copyright (C) 2008, Michael Larabel
+	Copyright (C) 2008 - 2009, Phoronix Media
+	Copyright (C) 2008 - 2009, Michael Larabel
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -22,33 +22,22 @@
 
 class install_dependencies implements pts_option_interface
 {
+	public static function required_function_sets()
+	{
+		return array("install");
+	}
+	public static function argument_checks()
+	{
+		return array(
+		new pts_argument_check(0, "!pts_empty", null, "The name of a test, suite, or result file must be entered.")
+		);
+	}
 	public static function run($r)
 	{
-		pts_load_function_set("install");
 		$r = array_map("strtolower", $r);
-
-		if(empty($r[0]))
-		{
-			echo "\nThe test or suite name to install external dependencies for must be supplied.\n";
-		}
-		else
-		{
-			if($r[0] == "phoronix-test-suite" || $r[0] == "pts" || $r[0] == "trondheim-pts")
-			{
-				$pts_dependencies = array("php-gd", "php-extras", "build-utilities");
-				$packages_to_install = array();
-				$continue_install = pts_package_generic_to_distro_name($packages_to_install, $pts_dependencies);
-
-				if($continue_install)
-				{
-					pts_install_packages_on_distribution_process($packages_to_install);
-				}
-			}
-			else
-			{
-				pts_install_package_on_distribution($r[0]);
-			}
-		}
+		$display_mode = pts_get_display_mode_object();
+		$passed_tests = array();
+		pts_install_package_on_distribution($display_mode, $r, $passed_tests);
 	}
 }
 
