@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2008, Phoronix Media
-	Copyright (C) 2008, Michael Larabel
+	Copyright (C) 2008 - 2010, Phoronix Media
+	Copyright (C) 2008 - 2010, Michael Larabel
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -25,9 +25,10 @@ class list_modules implements pts_option_interface
 	public static function run($r)
 	{
 		echo pts_string_header("Phoronix Test Suite - Modules");
-		foreach(pts_available_modules() as $module_file)
+		foreach(pts_available_modules() as $module)
 		{
-			echo new pts_user_module_details($module_file);
+			pts_load_module($module);
+			echo sprintf("%-22ls - %-32ls [%s]\n", $module, pts_module_call($module, "module_name") . " v" . pts_module_call($module, "module_version"), pts_module_call($module, "module_author"));
 		}
 		echo "\n";
 	}
