@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2008, Phoronix Media
-	Copyright (C) 2008, Michael Larabel
+	Copyright (C) 2008 - 2010, Phoronix Media
+	Copyright (C) 2008 - 2010, Michael Larabel
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -22,17 +22,18 @@
 
 class list_possible_dependencies implements pts_option_interface
 {
+	public static function required_function_sets()
+	{
+		return array("install_dependencies");
+	}
 	public static function run($r)
 	{
 		echo pts_string_header("Phoronix Test Suite - Possible External Dependencies");
-		$xml_parser = new tandem_XmlReader(XML_DISTRO_DIR . "generic-packages.xml");
-		$dependency_titles = $xml_parser->getXMLArrayValues(P_EXDEP_PACKAGE_TITLE);
-		sort($dependency_titles);
 
-		foreach($dependency_titles as $title)
-		{
-			echo "- " . $title . "\n";
-		}
+		$dependencies = array_map("pts_external_dependency_generic_title", pts_external_dependency_generic_packages());
+		sort($dependencies);
+
+		echo pts_text_list($dependencies);
 		echo "\n";
 	}
 }
