@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2008, Phoronix Media
-	Copyright (C) 2008, Michael Larabel
+	Copyright (C) 2008 - 2010, Phoronix Media
+	Copyright (C) 2008 - 2010, Michael Larabel
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -22,20 +22,28 @@
 
 class module_info implements pts_option_interface
 {
-	public static function run($r)
+	public static function argument_checks()
 	{
-		$module = strtolower($r[0]);
+		return array(
+		new pts_argument_check(0, "pts_is_module", null, "No module found.")
+		);
+	}
+	public static function run($args)
+	{
+		$module = $args[0];
+		pts_load_module($module);
+		echo pts_string_header(pts_module_call($module, "module_name") . " Module");
 
-		if(is_file(($path = MODULE_DIR . $module . ".php")) || is_file(($path = MODULE_DIR . $module . ".sh")))
+		if(in_array($args[0], pts_module_manager::attached_modules()))
 		{
-			$module = new pts_user_module_details($path);
-			echo $module->info_string();
-			echo "\n";
-		}
-		else
-		{
-			echo "\n" . $module . " is not recognized.\n";
+			echo "** This module is currently loaded. **\n";
 		}
+
+		echo "Version: " . pts_module_call($module, "module_version") . "\n";
+		echo "Author: " . pts_module_call($module, "module_author") . "\n";
+		echo "Description: " . pts_module_call($module, "module_description") . "\n";
+		echo "\n" . pts_module_call($module, "module_info") . "\n";
+		echo "\n";
 	}
 }
 
