@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2008, Phoronix Media
-	Copyright (C) 2008, Michael Larabel
+	Copyright (C) 2008 - 2010, Phoronix Media
+	Copyright (C) 2008 - 2010, Michael Larabel
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -22,25 +22,32 @@
 
 class remove_installed_test implements pts_option_interface
 {
+	public static function argument_checks()
+	{
+		return array(
+		new pts_argument_check(0, "pts_test_installed", null, "No installed test found.")
+		);
+	}
 	public static function run($r)
 	{
 		$identifier = $r[0];
 
-		if(pts_test_installed($identifier))
+		if(pts_bool_question("Are you sure you wish to remove the test " . $identifier . " (y/N)?", false))
 		{
-			if(pts_bool_question("Are you sure you wish to remove the test " . $identifier . " (y/N)?", false))
+			if($identifier == "all")
 			{
-				pts_remove(TEST_ENV_DIR . $identifier);
-				echo "\nThe " . $identifier . " test has been removed.\n\n";
+				$identifier = pts_installed_tests_array();
 			}
-			else
+
+			foreach(pts_to_array($identifier) as $install_identifier)
 			{
-				echo "\n";
+				pts_remove_installed_test($install_identifier);
+				echo "\nThe " . $install_identifier . " test has been removed.\n\n";
 			}
 		}
 		else
 		{
-			echo "\n" . $identifier . " is not installed.\n\n";
+			echo "\n";
 		}
 	}
 }
