@@ -22,30 +22,34 @@
 
 class result_file_to_pdf implements pts_option_interface
 {
+	public static function argument_checks()
+	{
+		return array(
+		new pts_argument_check(0, "pts_find_result_file", "result_file", "No result file was found.")
+		);
+	}
 	public static function run($r)
 	{
 		echo pts_string_header("Result File To PDF Converter");
 
-		if(pts_load_pdf_generator() == false)
+		if(is_file("/usr/share/php/fpdf/fpdf.php"))
+		{
+			include_once("/usr/share/php/fpdf/fpdf.php");
+		}
+		else
 		{
 			echo "\nThe FPDF library must be installed.\n\n";
 			return;
 		}
-		if(!is_file(($saved_results_file = SAVE_RESULTS_DIR . $r[0] . "/composite.xml")))
-		{
-			echo "\n" . $r[0] . " is not a saved results file.\n\n";
-			return;
-		}
 
-		$composite_xml = file_get_contents($saved_results_file);
-		putenv("JPG_DEBUG=true"); // Force to JPEG mode
-		pts_generate_graphs($composite_xml, SAVE_RESULTS_DIR . $r[0] . "/");
+		define("BILDE_RENDERER", "JPG"); // Force to JPEG mode
+		pts_generate_graphs($r[0], SAVE_RESULTS_DIR . $r[0] . "/");
 
-		$xml_parser = new pts_results_tandem_XmlReader($saved_results_file);
+		$xml_parser = new pts_results_tandem_XmlReader($r["result_file"]);
 		$pdf = new pts_pdf_template($xml_parser->getXMLValue(P_RESULTS_SUITE_TITLE), $xml_parser->getXMLValue(P_RESULTS_SUITE_NAME));
 
 		$pdf->AddPage();
-		$pdf->Image(MEDIA_DIR . "pts-308x160.png", 69, 85, 73, 38);
+		$pdf->Image(STATIC_DIR . "images/pts-308x160.png", 69, 85, 73, 38);
 		$pdf->Ln(120);
 		$pdf->WriteStatementCenter("www.phoronix-test-suite.com");
 		$pdf->Ln(15);
