@@ -1,9 +1,10 @@
 #!/bin/sh
 
-tar -xvf byte-benchmark-1.tar.gz
+tar -zxvf byte-benchmark-1.tar.gz
 cd bm/
 make clean
 make
+echo $? > ~/install-exit-status
 cd ..
 
 echo "#!/bin/sh
