@@ -1,12 +1,12 @@
 #!/bin/sh
 
-THIS_DIR=$(pwd)
-mkdir $THIS_DIR/lzma_
+mkdir $HOME/lzma_
 
-tar -xzf lzma-4.32.6.tar.gz
+tar -zxvf lzma-4.32.6.tar.gz
 cd lzma-4.32.6
-./configure --prefix=$THIS_DIR/lzma_
+./configure --prefix=$HOME/lzma_
 make -j $NUM_CPU_JOBS
+echo $? > ~/install-exit-status
 make install
 cd ..
 rm -rf lzma-4.32.6
