@@ -1,12 +1,12 @@
 #!/bin/sh
 
-THIS_DIR=$(pwd)
-mkdir $THIS_DIR/lame_
+mkdir $HOME/lame_
 
-tar -xvf lame-398-2.tar.gz
+tar -zxvf lame-398-2.tar.gz
 cd lame-398-2/
-./configure --prefix=$THIS_DIR/lame_
-make -j $NUM_CPU_JOBS
+./configure --prefix=$HOME/lame_
+make
+echo $? > ~/install-exit-status
 make install
 cd ..
 rm -rf lame-398-2/
@@ -14,5 +14,6 @@ rm -rf lame-398-2/
 echo "#!/bin/sh
 \$TIMER_START
 ./lame_/bin/lame -h \$TEST_EXTENDS/pts-trondheim.wav /dev/null 2>&1
+echo \$? > ~/test-exit-status
 \$TIMER_STOP" > lame
 chmod +x lame
