@@ -1,12 +1,12 @@
 #!/bin/sh
 
-THIS_DIR=$(pwd)
-mkdir $THIS_DIR/wavpack_
+mkdir $HOME/wavpack_
 
 tar -xjf wavpack-4.41.0.tar.bz2
 cd wavpack-4.41.0
-./configure --prefix=$THIS_DIR/wavpack_
+./configure --prefix=$HOME/wavpack_
 make -j $NUM_CPU_JOBS
+echo $? > ~/install-exit-status
 make install
 cd ..
 rm -rf wavpack-4.41.0/
@@ -14,5 +14,6 @@ rm -rf wavpack-4.41.0/
 echo "#!/bin/sh
 \$TIMER_START
 ./wavpack_/bin/wavpack -q -r -hhx2 -o - \$TEST_EXTENDS/pts-trondheim.wav > /dev/null 2>&1
+echo \$? > ~/test-exit-status
 \$TIMER_STOP" > encode-wavpack
 chmod +x encode-wavpack
