@@ -8,7 +8,7 @@ cd data/
 cat \$LOG_FILE | grep fps" > etqw
 chmod +x etqw
 
-tar -jxvf etqw-demo-files-3.tar.bz2
+tar -jxvf etqw-demo-files-4.tar.bz2
 mkdir data/base/demos
-mv -f pts.ndm data/base/demos/pts.ndm
-mv -f etqw-pts.cfg data/base/etqw-pts.cfg
+mv -f *.ndm data/base/demos/
+mv -f etqw-pts*.cfg data/base/
