@@ -6,10 +6,12 @@ cd fract-1.07b/
 patch -p0 < fract-scene.h.patch
 ./configure
 make
+echo $? > ~/install-exit-status
 cd ..
 
 echo "#!/bin/sh
 cd fract-1.07b/
-./src/fract \$@" > fract
+./src/fract \$@
+echo \$? > ~/test-exit-status" > fract
 chmod +x fract
 
