@@ -1,6 +1,7 @@
 <?php
-$log_file = file_get_contents(getenv("LOG_FILE"));
+$log_file = pts_read_log_file();
 $BENCHMARK_RESULTS = substr($log_file, strrpos($log_file, "average fps =") + 14);
 $BENCHMARK_RESULTS = substr($BENCHMARK_RESULTS, 0, strpos($BENCHMARK_RESULTS, "\n"));
-echo trim(substr($BENCHMARK_RESULTS, 0, strrpos($BENCHMARK_RESULTS, ".")));
+$BENCHMARK_RESULTS =  trim(substr($BENCHMARK_RESULTS, 0, strrpos($BENCHMARK_RESULTS, ".")));
+pts_report_numeric_result($BENCHMARK_RESULTS);
 ?>
