@@ -1,17 +1,16 @@
 #!/bin/sh
 
-THIS_DIR=$(pwd)
-mkdir $THIS_DIR/mpich2_
+mkdir $HOME/mpich2_
 
-tar -xvf mpich2-1.0.7.tar.gz
-cd mpich2-1.0.7/
-./configure --prefix=$THIS_DIR/mpich2_ --enable-fast=all --with-pm=gforker
+tar -zxvf mpich2-1.0.8p1.tar.gz
+cd mpich2-1.0.8p1/
+./configure --prefix=$HOME/mpich2_ --enable-fast=all --with-pm=gforker --disable-option-checking
 make
 make install
 cd ..
-rm -rf mpich2-1.0.7/
+rm -rf mpich2-1.0.8p1/
 
-tar -xvf mrbayes-3.1.2.tar.gz
+tar -zxvf mrbayes-3.1.2.tar.gz
 cd mrbayes-3.1.2/
 sed -i -e "s/MPI ?= no/MPI ?= yes/g" Makefile
 
@@ -22,7 +21,7 @@ if [ ! "$SSE" = "" ]
 fi
 #kludge to remove readline dependency. I don't think it affects the speed, so it can probably stay.
 sed -i -e "s/USEREADLINE ?= yes/USEREADLINE ?= no/g" Makefile
-make -j $NUM_CPU_JOBS PATH=$THIS_DIR/mpich2_/bin/:$PATH
+make -j $NUM_CPU_JOBS PATH=$HOME/mpich2_/bin/:$PATH
 
 cat>job.nex<<EOT
 begin mrbayes;
