@@ -1,9 +1,9 @@
 <?php
 
-$log_file = file_get_contents(getenv("LOG_FILE"));
+$log_file = pts_read_log_file();
 $BENCHMARK_RESULTS = substr($log_file, strrpos($log_file, "frames") + 7);
 $BENCHMARK_RESULTS = substr($BENCHMARK_RESULTS, strpos($BENCHMARK_RESULTS, "seconds") + 8);
 $BENCHMARK_RESULTS = substr($BENCHMARK_RESULTS, 0, strpos($BENCHMARK_RESULTS, ' fps'));
+pts_report_numeric_result($BENCHMARK_RESULTS);
 
-echo $BENCHMARK_RESULTS;
 ?>
