@@ -1,15 +1,17 @@
 #!/bin/sh
 
+rm -rf UrbanTerror UrbanTerror_
+
 unzip -o UrbanTerror_41_FULL.zip
 
-mv UrbanTerror/ UrbanTerror_/
+mv UrbanTerror UrbanTerror_
 cd UrbanTerror_/
 chmod +x ioUrbanTerror.i386
 chmod +x ioUrbanTerror.x86_64
 chmod +x ioUrbanTerror.app/Contents/MacOS/ioUrbanTerror.ub
 cd ..
 
-tar -xvf urbanterror-q3ut4-2.tar.gz
+tar -zxvf urbanterror-q3ut4-2.tar.gz
 mv -f autoexec.cfg UrbanTerror_/q3ut4/
 mv -f pts1.dm_68 UrbanTerror_/q3ut4/demos/
 
