@@ -1,28 +1,16 @@
 #!/bin/sh
 
-tar -xjf MPlayer-1.0rc2.tar.bz2
-
-THIS_DIR=$(pwd)
-mkdir $THIS_DIR/mplayer_
-
-cd MPlayer-1.0rc2/
-./configure --enable-xv --enable-xvmc --disable-ivtv --prefix=$THIS_DIR/mplayer_ > /dev/null
-make -j $NUM_CPU_JOBS
-make install
-cd ..
-rm -rf MPlayer-1.0rc2/
-
 cat > mplayer-runner.php << 'EOT'
 <?php
 
-$extensions_to_check = array("gl", "gl2", "xv", "xvmc");
+$extensions_to_check = array("gl", "gl2", "xv", "xvmc", "vdpau");
 $extensions_results = array();
 
 foreach($extensions_to_check as $extension)
 {
 	echo "Checking Video Output For: $extension\n";
 	$start_time = time();
-	echo shell_exec("./mplayer_/bin/mplayer -vo $extension -ao null " . getenv("TEST_EXTENDS") . "/pts-sample-playback-1.avi");
+	echo shell_exec(getenv("TEST_MPLAYER_BASE") . "/mplayer -vo $extension -ao null " . getenv("TEST_VIDEO_SAMPLE") . "/pts-sample-playback-1.avi");
 	$end_time = time();
 
 	$time_diff = $end_time - $start_time;
